distribution for a uccdf_fit object."> Skip to contents

Prints a short summary or plots either the K-selection curve or the confidence distribution for a uccdf_fit object.

Usage

# S3 method for class 'uccdf_fit'
print(x, ...)

# S3 method for class 'uccdf_fit'
plot(x, type = c("selection", "confidence"), ...)

Arguments

x

A fitted uccdf_fit object.

type

Plot type.

...

Additional arguments passed to the underlying graphics function.