Checks that an input object can be treated as a tabular clustering input.
Examples
dat <- simulate_mixed_data(n = 20, k = 2, seed = 1)
validated <- validate_input(dat, id_column = "sample_id")
nrow(validated)
#> [1] 20
Checks that an input object can be treated as a tabular clustering input.
dat <- simulate_mixed_data(n = 20, k = 2, seed = 1)
validated <- validate_input(dat, id_column = "sample_id")
nrow(validated)
#> [1] 20