distribution for a uccdf_fit object.">
uccdf_fit.Rd
Prints a short summary or plots either the K-selection curve or the confidence distribution for a uccdf_fit object.
uccdf_fit
# S3 method for class 'uccdf_fit' print(x, ...) # S3 method for class 'uccdf_fit' plot(x, type = c("selection", "confidence"), ...)
A fitted uccdf_fit object.
Plot type.
Additional arguments passed to the underlying graphics function.